@@ -4,7 +4,7 @@
 ###############################################################################
 # OpenLP - Open Source Lyrics Projection                                      #
 # --------------------------------------------------------------------------- #
-# Copyright (c) 2008-2016 OpenLP Developers                                   #
+# Copyright (c) 2008-2017 OpenLP Developers                                   #
 # --------------------------------------------------------------------------- #
 # This program is free software; you can redistribute it and/or modify it     #
 # under the terms of the GNU General Public License as published by the Free  #
@@ -129,21 +129,21 @@ class OpenLP(OpenLPMixin, QtWidgets.QApplication):
             application_stylesheet += WIN_REPAIR_STYLESHEET
         if application_stylesheet:
             self.setStyleSheet(application_stylesheet)
-        show_splash = Settings().value('core/show splash')
-        if show_splash:
+        can_show_splash = Settings().value('core/show splash')
+        if can_show_splash:
             self.splash = SplashScreen()
             self.splash.show()
         # make sure Qt really display the splash screen
         self.processEvents()
         # Check if OpenLP has been upgrade and if a backup of data should be created
-        self.backup_on_upgrade(has_run_wizard)
+        self.backup_on_upgrade(has_run_wizard, can_show_splash)
         # start the main app window
         self.main_window = MainWindow()
         Registry().execute('bootstrap_initialise')
         Registry().execute('bootstrap_post_set_up')
         Registry().initialise = False
         self.main_window.show()
-        if show_splash:
+        if can_show_splash:
             # now kill the splashscreen
             self.splash.finish(self.main_window)
             log.debug('Splashscreen closed')
@@ -177,6 +177,38 @@ class OpenLP(OpenLPMixin, QtWidgets.QApplication):
             self.shared_memory.create(1)
             return False
 
+    def is_data_path_missing(self):
+        """
+        Check if the data folder path exists.
+        """
+        data_folder_path = AppLocation.get_data_path()
+        if not os.path.exists(data_folder_path):
+            log.critical('Database was not found in: ' + data_folder_path)
+            status = QtWidgets.QMessageBox.critical(None, translate('OpenLP', 'Data Directory Error'),
+                                                    translate('OpenLP', 'OpenLP data folder was not found in:\n\n{path}'
+                                                                        '\n\nThe location of the data folder was '
+                                                                        'previously changed from the OpenLP\'s '
+                                                                        'default location. If the data was stored on '
+                                                                        'removable device, that device needs to be '
+                                                                        'made available.\n\nYou may reset the data '
+                                                                        'location back to the default location, '
+                                                                        'or you can try to make the current location '
+                                                                        'available.\n\nDo you want to reset to the '
+                                                                        'default data location? If not, OpenLP will be '
+                                                                        'closed so you can try to fix the the problem.')
+                                                    .format(path=data_folder_path),
+                                                    QtWidgets.QMessageBox.StandardButtons(QtWidgets.QMessageBox.Yes |
+                                                                                          QtWidgets.QMessageBox.No),
+                                                    QtWidgets.QMessageBox.No)
+            if status == QtWidgets.QMessageBox.No:
+                # If answer was "No", return "True", it will shutdown OpenLP in def main
+                log.info('User requested termination')
+                return True
+            # If answer was "Yes", remove the custom data path thus resetting the default location.
+            Settings().remove('advanced/data path')
+            log.info('Database location has been reset to the default settings.')
+            return False
+
     def hook_exception(self, exc_type, value, traceback):
         """
         Add an exception hook so that any uncaught exceptions are displayed in this window rather than somewhere where
@@ -192,9 +224,15 @@ class OpenLP(OpenLPMixin, QtWidgets.QApplication):
             self.exception_form = ExceptionForm()
         self.exception_form.exception_text_edit.setPlainText(''.join(format_exception(exc_type, value, traceback)))
         self.set_normal_cursor()
+        is_splash_visible = False
+        if hasattr(self, 'splash') and self.splash.isVisible():
+            is_splash_visible = True
+            self.splash.hide()
         self.exception_form.exec()
+        if is_splash_visible:
+            self.splash.show()
 
-    def backup_on_upgrade(self, has_run_wizard):
+    def backup_on_upgrade(self, has_run_wizard, can_show_splash):
         """
         Check if OpenLP has been upgraded, and ask if a backup of data should be made
 
@@ -207,6 +245,8 @@ class OpenLP(OpenLPMixin, QtWidgets.QApplication):
             Settings().setValue('core/application version', openlp_version)
         # If data_version is different from the current version ask if we should backup the data folder
         elif data_version != openlp_version:
+            if can_show_splash and self.splash.isVisible():
+                self.splash.hide()
             if QtWidgets.QMessageBox.question(None, translate('OpenLP', 'Backup'),
                                               translate('OpenLP', 'OpenLP has been upgraded, do you want to create '
                                                                   'a backup of OpenLPs data folder?'),
@@ -228,6 +268,8 @@ class OpenLP(OpenLPMixin, QtWidgets.QApplication):
                                                   % data_folder_backup_path)
             # Update the version in the settings
             Settings().setValue('core/application version', openlp_version)
+            if can_show_splash:
+                self.splash.show()
 
     def process_events(self):
         """
@@ -342,6 +384,7 @@ def main(args=None):
     application.setOrganizationName('OpenLP')
     application.setOrganizationDomain('openlp.org')
     application.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
+    application.setAttribute(QtCore.Qt.AA_DontCreateNativeWidgetSiblings, True)
     if args and args.portable:
         application.setApplicationName('OpenLPPortable')
         Settings.setDefaultFormat(Settings.IniFormat)
@@ -367,9 +410,13 @@ def main(args=None):
     Registry.create()
     Registry().register('application', application)
     application.setApplicationVersion(get_application_version()['version'])
-    # Instance check
+    # Check if an instance of OpenLP is already running. Quit if there is a running instance and the user only wants one
     if application.is_already_running():
         sys.exit()
+    # If the custom data path is missing and the user wants to restore the data path, quit OpenLP.
+    if application.is_data_path_missing():
+        application.shared_memory.detach()
+        sys.exit()
     # Remove/convert obsolete settings.
     Settings().remove_obsolete_settings()
     # First time checks in settings
